@@ -11,7 +11,7 @@ def mem_usage(obj, human=True):
     from humanize import naturalsize
     mem = __memory_usage(obj)
     shape = __shape(obj)
-    if human:
+    if human is True:
         if shape is not None:
             return '{0} \t{1}'.format(naturalsize(mem), shape)
         else:
