@@ -13,6 +13,7 @@ def np_sample(
     n: int,
     replace: bool = False,
     seed: Union[None, int] = None,
+    random_state: Union[None, int] = None,
     safe: bool = False,
 ) -> np.ndarray:
     """Randomly sample on axis 0 of a NumPy array
@@ -22,11 +23,17 @@ def np_sample(
         n (int): Number of samples to be draw
         replace (bool, optional): Repeat samples or not. Defaults to False.
         seed (Union[None, int], optional): Random seed for NumPy. Defaults to None.
+        random_state (Union[None, int], optional): Alias for seed. Defaults to None.
         safe (bool, optional) : Safely handle `n` or not. If True and replace = False, and n > len(a), then n = len(a)
 
     Returns:
         np.ndarray: A random sample
     """
+    assert random_state is None or seed is None
+
+    if random_state is not None:
+        seed = random_state
+
     if seed is not None:
         random_state = np.random.RandomState(seed)
     else:
